OiRA

Help

1. Préparation
2. Impliquer
3. Identification + Estimation
   1. 1 Commercial manned guarding
   2. Ω Risques ajoutés (par vous)
      1. Ω.1 The entrance floor is often wet
   - Sans réponse
   - A faire
   - OK
   - Attention
4. Plan d'action
5. Rapport
6. Avancement 0%

Si vous avez identifié des risques qui ne sont pas abordés par l’outil, vous pouvez les ajouter ici.

Important: Afin d’éviter les doublons, nous vous recommandons au préalable de bien parcourir l’ensemble des modules si ce n’est déjà fait.

Si vous ne devez pas ajouter de risques, veuillez continuer.

Précédent Passer au plan d'actions

Scroll to top
Back

## other-risks.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More